from distutils.core import setup
# from setuptools import setup

setup(
    name="miniretry",
    version="0.1.1",
    description="Retry helpers",
    author="Martin Czygan",
    author_email="martin.czygan@gmail.com",
    url="http://example.com",
    py_modules=["miniretry"],
    scripts=['bin/miniretry'],
)
